@@ -10,7 +10,7 @@ for (path in c(paste0(extdataPath, "/example"), paste0(extdataPath, "/example.be
 
     test_that("it determines n from FAM file", {
         bed <- BEDMatrix(path = path)
-        expect_equal(nrow(bed), nrow(CROCHET_EXTRACT_ENV$COMPARE_OBJECT))
+        expect_equal(nrow(bed), nrow(raw))
         expect_message(BEDMatrix(path = path), "Extracting number of samples and rownames from example\\.fam\\.\\.\\.")
     })
 
@@ -20,13 +20,13 @@ for (path in c(paste0(extdataPath, "/example"), paste0(extdataPath, "/example.be
 
     test_that("it determines rownames from FAM file", {
         bed <- BEDMatrix(path = path)
-        expect_equal(rownames(bed), rownames(CROCHET_EXTRACT_ENV$COMPARE_OBJECT))
+        expect_equal(rownames(bed), rownames(raw))
         expect_message(BEDMatrix(path = path), "Extracting number of samples and rownames from example\\.fam\\.\\.\\.")
     })
 
     test_that("it determines p from BIM file", {
         bed <- BEDMatrix(path = path)
-        expect_equal(ncol(bed), ncol(CROCHET_EXTRACT_ENV$COMPARE_OBJECT))
+        expect_equal(ncol(bed), ncol(raw))
         expect_message(BEDMatrix(path = path), "Extracting number of variants and colnames from example\\.bim\\.\\.\\.")
     })
 
@@ -36,12 +36,12 @@ for (path in c(paste0(extdataPath, "/example"), paste0(extdataPath, "/example.be
 
     test_that("it determines colnames from BIM file", {
         bed <- BEDMatrix(path = path)
-        expect_equal(colnames(bed), colnames(CROCHET_EXTRACT_ENV$COMPARE_OBJECT))
+        expect_equal(colnames(bed), colnames(raw))
         expect_message(BEDMatrix(path = path), "Extracting number of variants and colnames from example\\.bim\\.\\.\\.")
     })
 
     test_that("it accepts n and p if FAM or BIM file are present", {
-        bed <- BEDMatrix(path = path, n = nrow(CROCHET_EXTRACT_ENV$COMPARE_OBJECT), p = ncol(CROCHET_EXTRACT_ENV$COMPARE_OBJECT))
+        bed <- BEDMatrix(path = path, n = nrow(raw), p = ncol(raw))
         expect_equal(dimnames(bed), list(NULL, NULL))
     })
 
